@@ -22,12 +22,11 @@
 #define HAVE_ALLOCA_H 1
 #define HAVE_AIO_H 1
 #define HAVE_ARPA_INET_H 1
-#define HAVE_ASM_MSR_H 1
+/* #undef HAVE_ASM_MSR_H */
 #define HAVE_ASM_TERMBITS_H 1
 #define HAVE_BSEARCH 1
 #define HAVE_CRYPT_H 1
 #define HAVE_CURSES_H 1
-#define HAVE_CXXABI_H 1
 /* #undef HAVE_BFD_H */
 /* #undef HAVE_NCURSES_H */
 /* #undef HAVE_NDIR_H */
@@ -46,6 +45,7 @@
 #define HAVE_INTTYPES_H 1
 /* #undef HAVE_KQUEUE */
 #define HAVE_LIMITS_H 1
+#define HAVE_LINK_H 1
 #define HAVE_LINUX_UNISTD_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_H 1
@@ -87,6 +87,7 @@
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
+#define HAVE_SYS_SYSCALL_H 1
 /* #undef HAVE_SYS_TERMCAP_H */
 /* #undef HAVE_SYS_TIMEB_H */
 #define HAVE_SYS_TIMES_H 1
@@ -94,6 +95,8 @@
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_UN_H 1
 /* #undef HAVE_SYS_VADVISE_H */
+#define HAVE_SYS_STATVFS_H 1
+#define HAVE_UCONTEXT_H 1
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
@@ -109,7 +112,7 @@
 #define HAVE_SYS_PARAM_H 1
 
 /* Libraries */
-/* #undef HAVE_LIBPTHREAD */
+#define HAVE_LIBPTHREAD 1
 #define HAVE_LIBM 1
 #define HAVE_LIBDL 1
 #define HAVE_LIBRT 1
@@ -118,6 +121,7 @@
 #define HAVE_LIBCRYPT 1
 /* #undef HAVE_LIBMTMALLOC */
 /* #undef HAVE_LIBWRAP */
+/* #undef HAVE_SYSTEMD */
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
@@ -146,6 +150,7 @@
 #define HAVE_CUSERID 1
 #define HAVE_CXX_NEW 1
 /* #undef HAVE_DIRECTIO */
+#define HAVE_DLADDR 1
 #define HAVE_DLERROR 1
 #define HAVE_DLOPEN 1
 /* #undef HAVE_DOPRNT */
@@ -163,6 +168,7 @@
 #define HAVE_FSYNC 1
 #define HAVE_FTIME 1
 #define HAVE_GETADDRINFO 1
+#define HAVE_GETIFADDRS 1
 #define HAVE_GETCWD 1
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
@@ -214,9 +220,13 @@
 #define HAVE_POLL 1
 /* #undef HAVE_PORT_CREATE */
 #define HAVE_POSIX_FALLOCATE 1
+#define HAVE_LINUX_FALLOC_H 1
+/* #undef HAVE_FALLOCATE */
+/* #undef HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE */
 #define HAVE_PREAD 1
 #define HAVE_PAUSE_INSTRUCTION 1
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
+/* #undef HAVE_HMT_PRIORITY_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
@@ -290,7 +300,6 @@
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
-/* #undef HAVE_UCONTEXT */
 #define HAVE_VALLOC 1
 #define HAVE_VIDATTR 1
 #define HAVE_VIO_READ_BUFF 1
@@ -318,13 +327,15 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 #define STRUCT_DIRENT_HAS_D_INO 1
 /* #undef STRUCT_DIRENT_HAS_D_NAMLEN */
+#define STRUCT_TIMESPEC_HAS_TV_SEC 1
+#define STRUCT_TIMESPEC_HAS_TV_NSEC 1
 #define SPRINTF_RETURNS_INT 1
 
 #define USE_MB 1
 #define USE_MB_IDENT 1
 
 /* this means that valgrind headers and macros are available */
-/* #undef HAVE_VALGRIND */
+#define HAVE_VALGRIND 1
 
 /* this means WITH_VALGRIND - we change some code paths for valgrind */
 /* #undef HAVE_valgrind */
@@ -395,7 +406,7 @@
 
 #define SOCKET_SIZE_TYPE socklen_t
 
-#define HAVE_MBSTATE_T
+#define HAVE_MBSTATE_T 1
 
 #define MAX_INDEXES 64
 
@@ -405,6 +416,7 @@
 #define SIGNAL_RETURN_TYPE_IS_VOID 1
 #define RETSIGTYPE void
 #define VOID_SIGHANDLER 1
+#define HAVE_SIGHANDLER_T 1
 #define STRUCT_RLIMIT struct rlimit
 
 #ifdef __APPLE__
@@ -430,15 +442,15 @@
 #define HAVE_WCTYPE_H 1
 #define HAVE_WCHAR_H 1
 #define HAVE_LANGINFO_H 1
-#define HAVE_MBRLEN
+#define HAVE_MBRLEN 1
 /* #undef HAVE_MBSCMP */
-#define HAVE_MBSRTOWCS
-#define HAVE_WCRTOMB
-#define HAVE_MBRTOWC
-#define HAVE_WCSCOLL
-#define HAVE_WCSDUP
-#define HAVE_WCWIDTH
-#define HAVE_WCTYPE
+#define HAVE_MBSRTOWCS 1
+#define HAVE_WCRTOMB 1
+#define HAVE_MBRTOWC 1
+#define HAVE_WCSCOLL 1
+#define HAVE_WCSDUP 1
+#define HAVE_WCWIDTH 1
+#define HAVE_WCTYPE 1
 #define HAVE_ISWLOWER 1
 #define HAVE_ISWUPPER 1
 #define HAVE_TOWLOWER 1
@@ -452,25 +464,25 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRNCASECMP 1
 #define HAVE_STRDUP 1
-#define HAVE_LANGINFO_CODESET 
+#define HAVE_LANGINFO_CODESET  1
 #define HAVE_TCGETATTR 1
 #define HAVE_FLOCKFILE 1
 
 #define HAVE_WEAK_SYMBOL 1
 #define HAVE_ABI_CXA_DEMANGLE 1
-
+#define HAVE_ATTRIBUTE_CLEANUP 1
 
 #define HAVE_POSIX_SIGNALS 1
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-
+/* #undef HAVE_ERR_remove_thread_state */
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
-/* #undef MY_ATOMIC_MODE_RWLOCKS */
 /* #undef HAVE_GCC_ATOMIC_BUILTINS */
+/* #undef HAVE_GCC_C11_ATOMICS */
 /* #undef HAVE_SOLARIS_ATOMIC */
 #define HAVE_DECL_SHM_HUGETLB 1
 #define HAVE_LARGE_PAGES 1
@@ -481,7 +493,6 @@
 /* #undef _LARGE_FILES */
 #define _LARGEFILE_SOURCE 1
 /* #undef _LARGEFILE64_SOURCE */
-#define _FILE_OFFSET_BITS 64
 
 #define TIME_WITH_SYS_TIME 1
 
@@ -489,6 +500,7 @@
 
 #define SYSTEM_TYPE "Linux"
 #define MACHINE_TYPE "i686"
+#define DEFAULT_MACHINE "i686"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -514,19 +526,27 @@
 /* #undef strtoll */
 /* #undef strtoull */
 /* #undef vsnprintf */
+#if (_MSC_VER > 1800)
+#define tzname _tzname
+#define P_tmpdir "C:\\TEMP"
+#endif
 #if (_MSC_VER > 1310)
 # define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
 #endif
 #define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
+/* We don't want the min/max macros */
+#ifdef __WIN__
+#define NOMINMAX 1
+#endif
+
 /*
   MySQL features
 */
 #define ENABLED_LOCAL_INFILE 1
 #define ENABLED_PROFILING 1
 /* #undef EXTRA_DEBUG */
-/* #undef BACKUP_TEST */
 /* #undef CYBOZU */
 /* #undef USE_SYMDIR */
 
@@ -582,7 +602,8 @@
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
 #define HAVE_COMPRESS 1
-
+/* #undef HAVE_EncryptAes128Ctr */
+/* #undef HAVE_EncryptAes128Gcm */
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -599,15 +620,11 @@
 #define WITH_MYISAM_STORAGE_ENGINE 1
 #define WITH_MYISAMMRG_STORAGE_ENGINE 1
 #define WITH_HEAP_STORAGE_ENGINE 1
-#define WITH_INNOBASE_STORAGE_ENGINE 1
+/* #undef WITH_INNOBASE_STORAGE_ENGINE */
 #define WITH_XTRADB_STORAGE_ENGINE 1
 #define WITH_CSV_STORAGE_ENGINE 1
 #define WITH_PARTITION_STORAGE_ENGINE 1
 #define WITH_PERFSCHEMA_STORAGE_ENGINE 1
-/* #undef WITH_NDBCLUSTER_STORAGE_ENGINE */
-#if (WITH_NDBCLUSTER_STORAGE_ENGINE) && !defined(EMBEDDED_LIBRARY)
-# define HAVE_NDB_BINLOG 1
-#endif
 #define WITH_ARIA_STORAGE_ENGINE 1
 #define USE_ARIA_FOR_TMP_TABLES 1
 
@@ -623,17 +640,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 11
+#define MYSQL_VERSION_MINOR 1
+#define MYSQL_VERSION_PATCH 35
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.11"
+#define PACKAGE_STRING "MySQL Server 10.1.35"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.11"
-#define VERSION "10.0.11"
+#define PACKAGE_VERSION "10.1.35"
+#define VERSION "10.1.35"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "bundled jemalloc"
@@ -643,6 +660,12 @@
 #define SIZEOF_TIME_T 4
 /* #undef TIME_T_UNSIGNED */
 
+#ifndef EMBEDDED_LIBRARY
+/* #undef WSREP_INTERFACE_VERSION */
+#define WITH_WSREP 1
+#define WSREP_PROC_INFO 1
+#endif
+
 #ifdef _AIX
 /*
   AIX includes inttypes.h from sys/types.h
